%Script pro vypocet korekcni charakteristiky 1 200MW bloku tepelne
%elektrarny Tusimice
clear;
clc;
%Potrebne parametry
p1L = 15.8;                         % Tlak pary do VT (MPa)
p1P = 15.8;
t1L = 539.6;                        % Teplota pary do VT (C)
t1P = 539.6;
t2L = 535.5;                        % Teplota pary do ST (C)
t2P = 535.5;
Ms  = 4.4;                          % Mnozstvi vstrikovane vody do ST (t/h)
teL = 27.05;                        % Teplota emisni pary (C)
teP = 27.05;
tnvS = 220.3;                       % Teplota napajeci vody pred kotlem (C)
tvzL = 9.8;                         % Teplota vzduchu pred kotlem (C)
tvzP = 9.8;
tspL = 154.3;                       % Teplota spalin za lungstremy (C)
tspP = 150.6;
O2S = 5.5;                          % Obsah kysliku ve spalinach (%)
Ss  = 8;                            % Procento nedopalu ve spalinach (%)
pVS = 9;                            % Vlastni spotreba bloku (%)

%Vypocet zakladni a skutecne spotrebni charakteristiky
%Vypoctove koeficienty
Pstart = 120;
Pend   = 200;

P = Pstart;
i = 1;
while P <= Pend
    kes = 1 + pVS/100;
    kez = 1.125 - 5.2286E-4*P + 1.083E-6*P^2;
    k(1) = 0.000115*(16.18-(p1P+p1L)/2);
    k(2) = 0.000115*(540-(t1P+t1L)/2);
    k(3) = 0.0001*(540-(t2P+t2L)/2);
    k(4) = (0.000371 - 0.0000013*P)*(Ms + 19 - 0.15*P);
    dte = (teP+teL)/2-22.4676 - 0.066666*P;
    k(5) = -1.283E-4 + 1.136E-3*dte + 1.127E-5*dte^2;
    dtnv = tnvS - 191.3 - 0.283*P;
    k(6) = -5.857E-4 - 2E-4*dtnv - 6.31E-7*dtnv^2;
    k(7) = -0.00025*((tvzP+tvzL)/2 - 20);
    k(8) = 0.00025*((tspP+tspL)/2 - 177 + 0.336*P - 0.00143*P^2);
    dO2 = O2S/100 - 0.055;
    k(9) = -1.9E-4 + 1.757E-3*dO2 + 1.774E-4*dO2^2;
    dS = Ss - 93.428 + 0.0776*P - 0.0019*P^2;
    k(10) = -4.021E-5 + 4.229E-4*dS + 6.671E-6*dS^2;
    
    Sdp = 0.61489 - 0.00246*P + 6.3125E-6*P^2;
    
    Qz(i) = 23.556 + 0.101*P + 7.012E-4*P^2;
    Qs(i) = (Sdp + sum(k))*P/kes*(1 + kes - kez);
    
    P = P + 1;
    i = i + 1;
end

%Vykresleni charakteristiky
plot(Pstart:Pend,Qz,'r',Pstart:Pend,Qs,'b','Linewidth',2);
xlabel('Vykon P [MW]');
ylabel('Mnozstvi merneho paliva [tmp/h]');
legend('Qz - zakladni spotrebni charakteristika','Qs - skutecna spotrebni charakteristika',2);
title('Korekce spotrebni charakteristiky bloku 200 MW')
grid on;
